pub(crate) fn refresh_aura_snapshot_multiplier(
ctx: &mut HookCtx<'_>,
local: LocalAuraIdx,
multiplier: f64,
) -> boolExpand description
Refreshes a snapshot with a persistent damage multiplier without compounding it.
pub(crate) fn refresh_aura_snapshot_multiplier(
ctx: &mut HookCtx<'_>,
local: LocalAuraIdx,
multiplier: f64,
) -> boolRefreshes a snapshot with a persistent damage multiplier without compounding it.